@@ -18,7 +18,7 @@ fi
 # Sanity check docs that all modules are documented.
 # Ignore all packages and files named test*
 fail=0
-modules="$(find pmb/ -name "*.py" | grep -v '/__init__.py' | grep -v '/test' | grep -v '/conftest.py' | sort | sed 's|\.py$||' | sed 's|/|.|g')"
+modules="$(find pmb/ -name "*.py" | grep -v '/__init__.py' | grep -v '/conftest.py' | sort | sed 's|\.py$||' | sed 's|/|.|g')"
 for module in $modules; do
     if ! grep -q "automodule:: $module" docs/api/*.rst; then
         echo "Undocumented module: $module"
