@@ -7,6 +7,7 @@ from pmb.core.context import Context
 from pmb.core.pkgrepo import pkgrepo_default_path
 from pmb.helpers import logging
 from pmb.helpers.exceptions import NonBugError
+import contextlib
 import glob
 import heapq
 import json
@@ -20,7 +21,7 @@ import pmb.aportgen
 import pmb.config
 import pmb.config.pmaports
 from pmb.core import Config
-from pmb.types import PmbArgs
+from pmb.types import Apkbuild, PmbArgs
 import pmb.helpers.cli
 import pmb.helpers.devices
 import pmb.helpers.git
@@ -39,7 +40,7 @@ import subprocess
 
 def require_programs() -> None:
     missing = []
-    for program in pmb.config.required_programs.keys():
+    for program in pmb.config.required_programs:
         # Debian: some programs are in /usr/sbin, which is not in PATH
         # unless using sudo
         prog = shutil.which(program, path=pmb.config.host_path)
@@ -230,7 +231,7 @@ def ask_for_channel(config: Config) -> str:
 def ask_for_ui(deviceinfo: Deviceinfo) -> str:
     ui_list = pmb.helpers.ui.list_ui(deviceinfo.arch)
     hidden_ui_count = 0
-    if not deviceinfo.drm == "true":
+    if deviceinfo.drm != "true":
         for i in reversed(range(len(ui_list))):
             pkgname = f"postmarketos-ui-{ui_list[i][0]}"
             apkbuild = pmb.helpers.pmaports.get(pkgname, subpackages=False, must_exist=False)
@@ -242,7 +243,7 @@ def ask_for_ui(deviceinfo: Deviceinfo) -> str:
 
     # Get default
     default: Any = get_context().config.ui
-    if default not in dict(ui_list).keys():
+    if default not in dict(ui_list):
         default = pmb.config.defaults["ui"]
 
     logging.info(f"Available user interfaces ({len(ui_list) - 1}): ")
@@ -260,7 +261,7 @@ def ask_for_ui(deviceinfo: Deviceinfo) -> str:
         ret = pmb.helpers.cli.ask(
             "User interface", None, default, True, complete=ui_completion_list
         )
-        if ret in dict(ui_list).keys():
+        if ret in dict(ui_list):
             return ret
         logging.fatal(
             "ERROR: Invalid user interface specified, please type in one from the list above."
@@ -337,10 +338,8 @@ def ask_for_timezone() -> str:
             tzpath = os.path.realpath(localtime)
             tzpath = tzpath.rstrip()
             if os.path.exists(tzpath):
-                try:
+                with contextlib.suppress(BaseException):
                     _, tz = tzpath.split(zoneinfo_path)
-                except BaseException:
-                    pass
         if tz:
             logging.info(f"Your host timezone: {tz}")
             if pmb.helpers.cli.confirm("Use this timezone instead of GMT?", default=True):
@@ -367,8 +366,7 @@ def ask_for_provider_select(apkbuild: dict[str, Any], providers_cfg: dict[str, s
         for pkgname, pkg in providers:
             # Strip provider prefix if possible
             short = pkgname
-            if short.startswith(f"{select}-"):
-                short = short[len(f"{select}-") :]
+            short = short.removeprefix(f"{select}-")
 
             # Allow selecting the package using both short and long name
             providers_short[pkgname] = pkgname
@@ -457,12 +455,39 @@ def ask_for_device_kernel(config: Config, device: str) -> str:
         logging.info(f"* {type}: {kernels[type]}")
     while True:
         ret = pmb.helpers.cli.ask("Kernel", None, default, True, complete=kernels)
-        if ret in kernels.keys():
+        if ret in kernels:
             return ret
         logging.fatal("ERROR: Invalid kernel specified, please type in one from the list above.")
     return ret
 
 
+def ask_for_mainline_downstream() -> pmb.helpers.devices.DeviceCategory:
+    logging.info("What type of port are you creating?")
+    logging.info(
+        "* mainline: Port using upstream/mainline kernel, compatible with upstream user space."
+    )
+    logging.info(
+        "* downstream: Port using downstream kernel, using the original (e.g. Android) kernel "
+        "sources, at least partially incompatible with upstream user space."
+    )
+    port_type = pmb.helpers.cli.ask(
+        question="Type?",
+        choices=["mainline", "downstream"],
+        default=None,
+        validation_regex="mainline|downstream",
+        complete=["mainline", "downstream"],
+    )
+
+    match port_type:
+        # Mainline ports start out in the testing category
+        case "mainline":
+            return pmb.helpers.devices.DeviceCategory.TESTING
+        case "downstream":
+            return pmb.helpers.devices.DeviceCategory.DOWNSTREAM
+        case _:
+            raise ValueError(f"Unexpected port_type {port_type}")
+
+
 def ask_for_device(context: Context) -> tuple[str, bool, str]:
     """
     Prompt for the device vendor, model, and kernel.
@@ -537,10 +562,13 @@ def ask_for_device(context: Context) -> tuple[str, bool, str]:
                 current_vendor = vendor
                 continue
 
+            device_category = ask_for_mainline_downstream()
+
             # New port creation confirmed
             logging.info(f"Generating new aports for: {device}...")
-            pmb.aportgen.generate(f"device-{device}")
-            pmb.aportgen.generate(f"linux-{device}")
+            pmb.aportgen.generate(f"device-{device}", device_category=device_category)
+            if device_category == pmb.helpers.devices.DeviceCategory.DOWNSTREAM:
+                pmb.aportgen.generate(f"linux-{device}", device_category=device_category)
         elif device_category == pmb.helpers.devices.DeviceCategory.ARCHIVED:
             apkbuild = device_path.parent / "APKBUILD"
             archived = pmb.parse._apkbuild.archived(apkbuild) or "No reason given (this is a bug)"
@@ -782,6 +810,62 @@ def ask_for_locale(current_locale: str) -> str:
         return f"{ret}.UTF-8"
 
 
+def print_systemd_warning(device_exists: bool, apkbuild: Apkbuild, kernel: str) -> None:
+    kernel_version = None
+    if device_exists:
+        linuxdep = next((pkg for pkg in apkbuild["depends"] if pkg.startswith("linux-")), None)
+        if linuxdep is None:
+            kernel_subpkg = next(
+                subpkg for subpkg in apkbuild["subpackages"] if subpkg.endswith("-" + kernel)
+            )
+            linuxdep = next(
+                (
+                    dep
+                    for dep in apkbuild["subpackages"][kernel_subpkg]["depends"]
+                    if dep.startswith("linux-")
+                ),
+                None,
+            )
+        if linuxdep:
+            linux_apkbuild = pmb.helpers.pmaports.get(linuxdep, must_exist=False)
+            if linux_apkbuild:
+                kernel_version = linux_apkbuild["pkgver"]
+
+    pmaports_cfg = pmb.config.pmaports.read_config()
+    systemd_req = pmaports_cfg.get("systemd_linux_min_version", "5.4")
+    systemd_recommended = pmaports_cfg.get("systemd_linux_recommended_version", "5.7")
+    systemd_warning = not device_exists or (
+        kernel_version
+        and pmb.parse.version.compare(
+            kernel_version,
+            systemd_recommended,
+        )
+        == -1
+    )
+    if systemd_warning:
+        warning_text = ""
+        if kernel_version is None:
+            warning_text = (
+                f"WARNING: systemd requires kernel version {systemd_req}."
+                + " Installing systemd with older kernel may result in non-bootable system."
+            )
+        elif pmb.parse.version.compare(kernel_version, systemd_req) == -1:
+            warning_text = (
+                f"WARNING: Kernel version {kernel_version} "
+                + f"is lower than systemd's minimal requirement ({systemd_req})."
+                + " Choosing systemd may result in non-bootable system."
+            )
+        else:
+            warning_text = (
+                f"WARNING: Kernel version {kernel_version} "
+                + f"is lower than systemd's recommended kernel version ({systemd_recommended}). "
+                + "Some systemd features may be not available."
+            )
+        systemd_readme = "https://github.com/systemd/systemd/blob/main/README"
+        warning_text += f" Get more information for systemd requirements at {systemd_readme}"
+        logging.warning(warning_text)
+
+
 def frontend(args: PmbArgs) -> None:
     # Work folder (needs to be first, so we can create chroots early)
     config = get_context().config
@@ -805,7 +889,7 @@ def frontend(args: PmbArgs) -> None:
     pmb.helpers.other.migrate_work_folder()
 
     # Clone pmaports
-    pmb.config.pmaports.init()
+    pmb.config.pmaports.init(args.shallow_initial_clone)
 
     # Choose release channel, possibly switch pmaports branch
     channel = ask_for_channel(config)
@@ -846,6 +930,7 @@ def frontend(args: PmbArgs) -> None:
     config.ui_extras = ask_for_ui_extras(config, ui)
 
     # systemd
+    print_systemd_warning(device_exists, apkbuild, config.kernel)
     config.systemd = ask_for_systemd(config, ui)
 
     ask_for_provider_select_pkg(f"postmarketos-ui-{ui}", config.providers)
