@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 from __future__ import annotations
 
+import ctypes
 import enum
 from pathlib import Path, PosixPath, PurePosixPath
 import platform
@@ -9,6 +10,30 @@ import platform
 # Initialised at the bottom
 _cached_native_arch: Arch
 
+# https://github.com/torvalds/linux/blob/d4b779985a6c853be5693fa6e8994034f8492abc/include/uapi/linux/personality.h#L56
+PER_LINUX32 = 0x0008
+
+
+def cpu_is_32_bit_capable() -> bool:
+    """Check whether the host CPU is capable of executing 32-bit binaries.
+
+    This is done by calling personality(PER_LINUX32), similar to how
+    util-linux does it
+    """
+    # https://github.com/util-linux/util-linux/blob/15de47b9c955b9e3451d864e16dd646169316331/sys-utils/lscpu-cputype.c#L714
+    personality = ctypes.CDLL(None).personality
+    personality.restype = ctypes.c_int
+    personality.argtypes = [ctypes.c_ulong]
+    # personality sets the process execution domain, so we need to revert it immediately
+    # if it succeeded. It returns the old process execution domain.
+    result = personality(PER_LINUX32)
+
+    if result == -1:
+        return False
+    else:
+        personality(result)
+        return True
+
 
 class Arch(enum.Enum):
     """Supported architectures according to the Alpine
@@ -63,6 +88,10 @@ class Arch(enum.Enum):
                 return Arch.armhf
             case "armv7l" | "armv8l":
                 return Arch.armv7
+            case "ppc64le":
+                return Arch.ppc64le
+            case "loongarch64":
+                return Arch.loongarch64
             case _:
                 raise ValueError(f"Unsupported machine type '{machine_type}'")
 
@@ -89,6 +118,7 @@ class Arch(enum.Enum):
             Arch.riscv64,
             Arch.s390x,
             Arch.ppc64le,
+            Arch.loongarch64,
             Arch.native(),
         }
 
@@ -120,6 +150,8 @@ class Arch(enum.Enum):
                 return "powerpc"
             case Arch.s390x:
                 return "s390"
+            case Arch.loongarch64 | Arch.loongarch32 | Arch.loongarchx32:
+                return "loongarch"
             case _:
                 return self.value
 
@@ -134,6 +166,13 @@ class Arch(enum.Enum):
             case _:
                 return self.value
 
+    def requires_efi(self) -> bool:
+        match self:
+            case Arch.loongarch64:
+                return True
+            case _:
+                return False
+
     def alpine_triple(self) -> str:
         """Get the cross compiler triple for this architecture on Alpine."""
         match self:
@@ -192,6 +231,8 @@ class Arch(enum.Enum):
                 return "386"
             case Arch.x86_64:
                 return "amd64"
+            case Arch.loongarch64:
+                return "loong64"
             case _:
                 raise ValueError(f"Can not map architecture '{self}' to Go arch")
 
@@ -200,22 +241,23 @@ class Arch(enum.Enum):
         if self == Arch.native():
             return False
 
+        # Currently, the only case where CPU emulation isn't required for non-host
+        # architectures is where the CPU supports 32-bit execution
+        if not cpu_is_32_bit_capable():
+            return True
+
         # Other cases: host arch on the left, target archs on the right
         not_required = {
             Arch.x86_64: [Arch.x86],
             Arch.armv7: [Arch.armel, Arch.armhf],
             Arch.aarch64: [Arch.armv7],
+            Arch.loongarch64: [Arch.loongarch32],
         }
-        if Arch.native() in not_required:
-            if self in not_required[Arch.native()]:
-                return False
-
-        # No match: then it's required
-        return True
+        return not (Arch.native() in not_required and self in not_required[Arch.native()])
 
     # Magic to let us use an arch as a Path element
     def __truediv__(self, other: object) -> Path:
-        if isinstance(other, PosixPath) or isinstance(other, PurePosixPath):
+        if isinstance(other, (PosixPath, PurePosixPath)):
             # Convert the other path to a relative path
             # FIXME: we should avoid creating absolute paths that we actually want
             # to make relative to the chroot...
@@ -232,7 +274,7 @@ class Arch(enum.Enum):
         return NotImplemented
 
     def __rtruediv__(self, other: object) -> Path:
-        if isinstance(other, PosixPath) or isinstance(other, PurePosixPath):
+        if isinstance(other, (PosixPath, PurePosixPath)):
             # Important to produce a new Path object here, otherwise we
             # end up with one object getting shared around and modified
             # and lots of weird stuff happens.
