@@ -10,7 +10,7 @@ import pmb.chroot
 import pmb.config.pmaports
 from pmb.core.arch import Arch
 from pmb.core.chroot import Chroot
-from pmb.types import PathString
+from pmb.types import PathString, RunOutputTypePopen
 import pmb.helpers.cli
 import pmb.helpers.repo
 import pmb.helpers.run
@@ -73,7 +73,7 @@ def update_repository_list(
     if path.exists():
         pmb.helpers.run.root(["rm", path])
     for line in lines_new:
-        pmb.helpers.run.root(["sh", "-c", "echo " f"{shlex.quote(line)} >> {path}"])
+        pmb.helpers.run.root(["sh", "-c", f"echo {shlex.quote(line)} >> {path}"])
     update_repository_list(
         root,
         user_repository=user_repository,
@@ -102,7 +102,7 @@ def _prepare_fifo() -> Path:
     return fifo
 
 
-def _create_command_with_progress(command, fifo):
+def _create_command_with_progress(command: list[str], fifo: Path) -> list[str]:
     """Build a full apk command from a subcommand, set up to redirect progress into a fifo.
 
     :param command: apk subcommand in list form
@@ -110,13 +110,13 @@ def _create_command_with_progress(command, fifo):
     :returns: full command in list form
     """
     flags = ["--progress-fd", "3"]
-    command_full = [command[0]] + flags + command[1:]
+    command_full = [command[0], *flags, *command[1:]]
     command_flat = pmb.helpers.run_core.flat_cmd([command_full])
     command_flat = f"exec 3>{fifo}; {command_flat}"
     return ["sh", "-c", command_flat]
 
 
-def _compute_progress(line):
+def _compute_progress(line: str) -> float:
     """Compute the progress as a number between 0 and 1.
 
     :param line: line as read from the progress fifo
@@ -124,7 +124,7 @@ def _compute_progress(line):
     """
     if not line:
         return 1
-    cur_tot = line.rstrip().split("/")
+    cur_tot = line.split(" ")[0].rstrip().split("/")
     if len(cur_tot) != 2:
         return 0
     cur = float(cur_tot[0])
@@ -132,7 +132,7 @@ def _compute_progress(line):
     return cur / tot if tot > 0 else 0
 
 
-def _apk_with_progress(command: Sequence[str]) -> None:
+def _apk_with_progress(command: list[str]) -> None:
     """Run an apk subcommand while printing a progress bar to STDOUT.
 
     :param command: apk subcommand in list form
@@ -141,17 +141,19 @@ def _apk_with_progress(command: Sequence[str]) -> None:
     fifo = _prepare_fifo()
     command_with_progress = _create_command_with_progress(command, fifo)
     log_msg = " ".join(command)
-    with pmb.helpers.run.root(["cat", fifo], output="pipe") as p_cat:
-        with pmb.helpers.run.root(command_with_progress, output="background") as p_apk:
-            while p_apk.poll() is None:
-                p_cat_stdout = p_cat.stdout
-                if p_cat_stdout is None:
-                    raise RuntimeError("cat process had no stdout?")
-                line = p_cat_stdout.readline().decode("utf-8")
-                progress = _compute_progress(line)
-                pmb.helpers.cli.progress_print(progress)
-            pmb.helpers.cli.progress_flush()
-            pmb.helpers.run_core.check_return_code(p_apk.returncode, log_msg)
+    with (
+        pmb.helpers.run.root(["cat", fifo], output=RunOutputTypePopen.PIPE) as p_cat,
+        pmb.helpers.run.root(command_with_progress, output=RunOutputTypePopen.BACKGROUND) as p_apk,
+    ):
+        while p_apk.poll() is None:
+            p_cat_stdout = p_cat.stdout
+            if p_cat_stdout is None:
+                raise RuntimeError("cat process had no stdout?")
+            line = p_cat_stdout.readline().decode("utf-8")
+            progress = _compute_progress(line)
+            pmb.helpers.cli.progress_print(progress)
+        pmb.helpers.cli.progress_flush()
+        pmb.helpers.run_core.check_return_code(p_apk.returncode, log_msg)
 
 
 def _prepare_cmd(command: Sequence[PathString], chroot: Chroot | None) -> list[str]:
@@ -164,35 +166,39 @@ def _prepare_cmd(command: Sequence[PathString], chroot: Chroot | None) -> list[s
     # Our _apk_with_progress() wrapper also need --no-progress, since all that does is
     # prevent apk itself from rendering progress bars. We instead want it to tell us
     # the progress so we can render it. So we always set --no-progress.
-    _command: list[str] = [str(config.work / "apk.static"), "--no-progress"]
+    command_: list[str] = [str(config.work / "apk.static"), "--no-progress"]
     if chroot:
         cache_dir = config.work / f"cache_apk_{chroot.arch}"
-        _command.extend(
+        command_.extend(
             [
                 "--root",
                 str(chroot.path),
                 "--arch",
                 str(chroot.arch),
-                "--cache-dir",
-                str(cache_dir),
             ]
         )
+
+        if os.getenv("PMB_APK_NO_CACHE") == "1":
+            command_.extend(["--no-cache"])
+        else:
+            command_.extend(["--cache-dir", str(cache_dir)])
+
         local_repos = pmb.helpers.repo.urls(
             user_repository=config.work / "packages", mirrors_exclude=True
         )
         for repo in local_repos:
-            _command.extend(["--repository", repo])
+            command_.extend(["--repository", repo])
     if get_context().offline:
-        _command.append("--no-network")
+        command_.append("--no-network")
 
     for c in command:
-        _command.append(os.fspath(c))
+        command_.append(os.fspath(c))
 
         # Always be non-interactive
         if c == "add":
-            _command.append("--no-interactive")
+            command_.append("--no-interactive")
 
-    return _command
+    return command_
 
 
 def run(command: Sequence[PathString], chroot: Chroot, with_progress: bool = True) -> None:
@@ -203,24 +209,28 @@ def run(command: Sequence[PathString], chroot: Chroot, with_progress: bool = Tru
     :param chroot: chroot to run the command in
     :raises RuntimeError: when the apk command fails
     """
-    _command = _prepare_cmd(command, chroot)
+    command_ = _prepare_cmd(command, chroot)
 
     # Sanity checks. We should avoid accidentally writing to
     # /var/cache/apk on the host!
     if "add" in command:
-        if "--no-interactive" not in _command:
+        if "--no-interactive" not in command_:
             raise RuntimeError(
                 "Encountered an 'apk add' command without --no-interactive! This is a bug."
             )
-        if "--cache-dir" not in _command:
+        if os.getenv("PMB_APK_NO_CACHE") == "1" and "--no-cache" not in command_:
+            raise RuntimeError(
+                "Encountered an 'apk add' command without --no-cache! This is a bug."
+            )
+        if os.getenv("PMB_APK_NO_CACHE") != "1" and "--cache-dir" not in command_:
             raise RuntimeError(
                 "Encountered an 'apk add' command without --cache-dir! This is a bug."
             )
 
     if with_progress:
-        _apk_with_progress(_command)
+        _apk_with_progress(command_)
     else:
-        pmb.helpers.run.root(_command)
+        pmb.helpers.run.root(command_)
 
 
 def cache_clean(arch: Arch) -> None:
@@ -271,13 +281,13 @@ def cache_clean(arch: Arch) -> None:
     ]
 
     command += ["cache", "clean"]
-    _command = _prepare_cmd(command, None)
+    command_ = _prepare_cmd(command, None)
 
     pmb.helpers.apk_static.init()
-    pmb.helpers.run.root(_command)
+    pmb.helpers.run.root(command_)
 
 
-def check_outdated(version_installed, action_msg):
+def check_outdated(version_installed: str, action_msg: str) -> None:
     """Check if the provided alpine version is outdated.
 
     This depends on the alpine mirrordir (edge, v3.12, ...) related to currently checked out
