@@ -34,8 +34,7 @@ GITLAB_HOSTS = [
 
 
 def init_req_headers() -> None:
-    global req_headers
-    global req_headers_github
+    global req_headers, req_headers_github
     # Only initialize them once
     if req_headers and req_headers_github:
         return
@@ -140,10 +139,7 @@ def upgrade_git_package(args: PmbArgs, pkgname: str, package: Apkbuild) -> None:
     sha_new = verinfo["sha"]
 
     # Format the new pkgver, keep the value before _git the same
-    if package["pkgver"] == "9999":
-        pkgver = package["_pkgver"]
-    else:
-        pkgver = package["pkgver"]
+    pkgver = package["_pkgver"] if package["pkgver"] == "9999" else package["pkgver"]
 
     pkgver_match = re.match(r"([\d.]+)_git", pkgver)
     if pkgver_match is None:
@@ -233,10 +229,7 @@ def upgrade_stable_package(args: PmbArgs, pkgname: str, package: Apkbuild) -> No
         logging.info(f"{pkgname}: up-to-date")
         return
 
-    if package["pkgver"] == "9999":
-        pkgver = package["_pkgver"]
-    else:
-        pkgver = package["pkgver"]
+    pkgver = package["_pkgver"] if package["pkgver"] == "9999" else package["pkgver"]
 
     pkgver_new = version
 
