@@ -11,6 +11,7 @@ from pmb.core.pkgrepo import (
 from pmb.helpers import logging
 from pmb.helpers.exceptions import NonBugError
 from pmb.helpers.toml import load_toml_file
+from pmb.types import RunOutputTypeDefault
 import os
 
 import pmb.chroot
@@ -33,7 +34,7 @@ def get_custom_valid_options() -> list[str]:
     pmb.parse.kconfigcheck.sanity_check(kconfigcheck_toml)
 
     # Add options like "pmb:kconfigcheck-libcamera"
-    for section in kconfigcheck_toml.keys():
+    for section in kconfigcheck_toml:
         if not section.startswith("category:"):
             continue
         # section looks like: "category:input.>=0.0.0.all"
@@ -41,7 +42,7 @@ def get_custom_valid_options() -> list[str]:
         ret += [f"pmb:kconfigcheck-{category}"]
 
     # Add aliases like "pmb:kconfigcheck-community"
-    for alias in kconfigcheck_toml["aliases"].keys():
+    for alias in kconfigcheck_toml["aliases"]:
         ret += [f"pmb:kconfigcheck-{alias}"]
 
     return ret
@@ -94,7 +95,7 @@ def check(pkgnames: Sequence[str]) -> None:
 
     # For each pkgrepo run the linter on the relevant packages
     has_failed = False
-    for pkgrepo, apkbuild_paths in apkbuilds.items():
+    for apkbuild_paths in apkbuilds.values():
         # We search for the pkgnames in both the normal and systemd repository,
         # so unless the pkgname exists in both the apkbuild_paths is empty for
         # one of them and needs to be skipped here. This is not very elegant,
@@ -104,7 +105,7 @@ def check(pkgnames: Sequence[str]) -> None:
         if pmb.chroot.user(
             ["apkbuild-lint", *apkbuild_paths],
             check=False,
-            output="stdout",
+            output=RunOutputTypeDefault.STDOUT,
             working_dir=dest_paths[pkgrepo_name(repo)],
             env={"CUSTOM_VALID_OPTIONS": " ".join(get_custom_valid_options())},
         ):
