@@ -20,7 +20,7 @@ import pmb.config.pmaports
 from pmb.helpers.locale import get_xkb_layout
 from pmb.parse.deviceinfo import Deviceinfo
 from pmb.core import Config
-from pmb.types import Env, PartitionLayout, PmbArgs
+from pmb.types import Env, PartitionLayout, PmbArgs, RunOutputTypeDefault
 import pmb.helpers.devices
 from pmb.helpers.mount import mount_device_rootfs
 import pmb.helpers.run
@@ -286,7 +286,9 @@ def setup_login(args: PmbArgs, config: Config, chroot: Chroot) -> None:
         else:
             while True:
                 try:
-                    pmb.chroot.root(["passwd", config.user], chroot, output="interactive")
+                    pmb.chroot.root(
+                        ["passwd", config.user], chroot, output=RunOutputTypeDefault.INTERACTIVE
+                    )
                     break
                 except RuntimeError:
                     logging.info("WARNING: Failed to set the password. Try it one more time.")
@@ -325,10 +327,9 @@ def copy_ssh_keys(config: Config) -> None:
         return
 
     authorized_keys = Chroot.native() / "tmp/authorized_keys"
-    outfile = open(authorized_keys, "w")
-    for key in keys:
-        outfile.write(f"{key}")
-    outfile.close()
+    with open(authorized_keys, "w") as outfile:
+        for key in keys:
+            outfile.write(f"{key}")
 
     target = Chroot.native() / "mnt/install/home/" / config.user / ".ssh"
     pmb.helpers.run.root(["mkdir", target])
@@ -350,7 +351,9 @@ def setup_keymap(config: Config) -> None:
     options = deviceinfo.keymaps.split(" ")
     if config.keymap != "" and config.keymap is not None and config.keymap in options:
         layout, variant = config.keymap.split("/")
-        pmb.chroot.root(["setup-keymap", layout, variant], chroot, output="interactive")
+        pmb.chroot.root(
+            ["setup-keymap", layout, variant], chroot, output=RunOutputTypeDefault.INTERACTIVE
+        )
 
         # Check xorg config
         xconfig = None
@@ -607,9 +610,9 @@ def generate_binary_list(args: PmbArgs, chroot: Chroot, step: int) -> list[tuple
     binaries = (pmb.parse.deviceinfo().sd_embed_firmware or "").split(",")
 
     for binary_offset in binaries:
-        binary, _offset = binary_offset.split(":")
+        binary, offset_ = binary_offset.split(":")
         try:
-            offset = int(_offset)
+            offset = int(offset_)
         except ValueError:
             raise RuntimeError(f"Value for firmware binary offset is not valid: {offset}")
         binary_path = chroot / "usr/share" / binary
@@ -742,15 +745,18 @@ def sanity_check_disk_size(args: PmbArgs) -> None:
     human = f"{size / 2 / 1024 / 1024:.2f} GiB"
 
     # Warn if the size is larger than 100GiB
-    if not args.assume_yes and size > (100 * 2 * 1024 * 1024):
-        if not pmb.helpers.cli.confirm(
+    if (
+        not args.assume_yes
+        and size > (100 * 2 * 1024 * 1024)
+        and not pmb.helpers.cli.confirm(
             f"WARNING: The target disk ({devpath}) "
             "is larger than a usual SD card "
             "(>100GiB). Are you sure you want to "
             f"overwrite this {human} disk?",
             no_assumptions=True,
-        ):
-            raise RuntimeError("Aborted.")
+        )
+    ):
+        raise RuntimeError("Aborted.")
 
 
 def get_ondev_pkgver(args: PmbArgs) -> str:
@@ -823,10 +829,7 @@ def create_crypttab(args: PmbArgs, layout: PartitionLayout | None, chroot: Chroo
     :param layout: partition layout from get_partition_layout() or None
     :param suffix: of the chroot, which crypttab will be created to
     """
-    if layout:
-        root_dev = Path(f"/dev/installp{layout['root']}")
-    else:
-        root_dev = Path("/dev/install")
+    root_dev = Path(f"/dev/installp{layout['root']}") if layout else Path("/dev/install")
 
     luks_uuid = get_uuid(args, root_dev)
     crypttab = f"root UUID={luks_uuid} none luks\n"
@@ -1091,7 +1094,7 @@ def print_flash_info(
         logging.info(f"  {Chroot.rootfs(device) / 'boot/boot.img'}")
         logging.info("  (NOTE: This is not necessary if using a custom bootloader like U-Boot)")
 
-    if "boot" in flasher_actions:
+    if "boot" in flasher_actions or "boot_gki" in flasher_actions:
         logging.info(
             "  (NOTE: " + method + " also supports booting"
             " the kernel/initramfs directly without flashing."
@@ -1120,6 +1123,7 @@ def print_flash_info(
 def install_recovery_zip(args: PmbArgs, device: str, arch: Arch, steps: int) -> None:
     logging.info(f"*** ({steps}/{steps}) CREATING RECOVERY-FLASHABLE ZIP ***")
     chroot = Chroot(ChrootType.BUILDROOT, arch)
+    pmb.chroot.init(chroot)
     mount_device_rootfs(Chroot.rootfs(device), chroot)
     pmb.install.recovery.create_zip(args, chroot, device)
 
@@ -1395,8 +1399,7 @@ def create_device_rootfs(args: PmbArgs, step: int, steps: int) -> None:
     # installed a hook without pmbootstrap - see #69 for more info)
     # Packages will be built if necessary as part of this step
     pmb.chroot.apk.install(install_packages, chroot)
-    flavor = pmb.chroot.other.kernel_flavor_installed(chroot)
-    pmb.chroot.initfs.build(flavor, chroot)
+    pmb.chroot.initfs.build(chroot)
 
     # Set the user password
     setup_login(args, config, chroot)
@@ -1488,7 +1491,7 @@ def install(args: PmbArgs) -> None:
         device,
         deviceinfo,
         args.split,
-        True if args.disk and args.disk.is_absolute() else False,
+        bool(args.disk and args.disk.is_absolute()),
         args.single_partition,
     )
     print_sshd_info(args)
