@@ -1,5 +1,6 @@
 # Copyright 2024 Caleb Connolly
 # SPDX-License-Identifier: GPL-3.0-or-later
+from pathlib import Path
 
 import pmb.config
 from pmb.core.config import SystemdConfig
@@ -7,7 +8,7 @@ from pmb.core.config import SystemdConfig
 """Test the config file serialization and deserialization."""
 
 
-def test_load(config_file):
+def test_load(config_file: Path) -> None:
     config = pmb.config.load(config_file)
     assert config.build_default_device_arch
     assert config.ccache_size == "5G"
